<!DOCTYPE TS><TS>
<context>
    <name>String::DayOfWeek</name>
    <message>
        <source>MON</source>
        <translation>LUN</translation>
    </message>
    <message>
        <source>TUE</source>
        <translation>MAR</translation>
    </message>
    <message>
        <source>WED</source>
        <translation>MIE</translation>
    </message>
    <message>
        <source>THU</source>
        <translation>JUE</translation>
    </message>
    <message>
        <source>FRI</source>
        <translation>VIE</translation>
    </message>
    <message>
        <source>SAT</source>
        <translation>SAB</translation>
    </message>
    <message>
        <source>SUN</source>
        <translation>DOM</translation>
    </message>
</context>
<context>
    <name>String::WeatherType</name>
    <message>
        <source>Cloudy</source>
        <translation>Nublado</translation>
    </message>
    <message>
        <source>Mostly Cloudy</source>
        <translation>Bastante nublado</translation>
    </message>
    <message>
        <source>Partly Cloudy</source>
        <translation>Alguna nube</translation>
    </message>
    <message>
        <source>Light Rain</source>
        <translation>Liega lluvia</translation>
    </message>
    <message>
        <source>Showers</source>
        <translation>Lluvias</translation>
    </message>
    <message>
        <source>Rain</source>
        <translation>Lluvia</translation>
    </message>
    <message>
        <source>AM Showers</source>
        <translation>Lluvias de mañana</translation>
    </message>
    <message>
        <source>Fog</source>
        <translation>Niebla</translation>
    </message>
    <message>
        <source>Few Showers</source>
        <translation>Algunas lluvias</translation>
    </message>
    <message>
        <source>Mostly Sunny</source>
        <translation>Bastante soleado</translation>
    </message>
    <message>
        <source>Sunny</source>
        <translation>Soleado</translation>
    </message>
    <message>
        <source>Scattered Flurries</source>
        <translation>Nubes dispersas</translation>
    </message>
    <message>
        <source>AM Clouds/PM Sun</source>
        <translation>Nubes de mañana, sol de tarde</translation>
    </message>
    <message>
        <source>Isolated T-Storms</source>
        <translation>Tormentas aisladas</translation>
    </message>
    <message>
        <source>Scattered Thunderstorms</source>
        <translation>Tormentas dispersas</translation>
    </message>
    <message>
        <source>PM Showers</source>
        <translation>Chubascos de tarde</translation>
    </message>
    <message>
        <source>PM Showers/Wind</source>
        <translation>Llivias/Viento de tarde</translation>
    </message>
    <message>
        <source>Rain/Snow Showers</source>
        <translation>Chubascos de Lluvia/Nieve </translation>
    </message>
    <message>
        <source>Few Snow Showers</source>
        <translation>Lgunos chubascos de nieve</translation>
    </message>
    <message>
        <source>Cloudy/Wind</source>
        <translation>Nubes y viento</translation>
    </message>
    <message>
        <source>Flurries/Wind</source>
        <translation>Claros y viento</translation>
    </message>
    <message>
        <source>Mostly Cloudy/Windy</source>
        <translation>Bastante nublado/viento</translation>
    </message>
    <message>
        <source>Rain/Thunder</source>
        <translation>Lluvia/Truenos</translation>
    </message>
    <message>
        <source>Partly Cloudy/Windy</source>
        <translation>Algo nublado/viento</translation>
    </message>
    <message>
        <source>AM Rain/Snow Showers</source>
        <translation>Lluvia/viento matinales</translation>
    </message>
    <message>
        <source>Light Rain/Wind</source>
        <translation>Ligera lluvia/viento</translation>
    </message>
    <message>
        <source>Showers/Wind</source>
        <translation>Chubascos/viento</translation>
    </message>
    <message>
        <source>Mostly Sunny/Wind</source>
        <translation>Bastante soleado/viento</translation>
    </message>
    <message>
        <source>Flurries</source>
        <translation>Claros</translation>
    </message>
    <message>
        <source>Rain/Wind</source>
        <translation>Lluvia y viento</translation>
    </message>
    <message>
        <source>Sct Flurries/Wind</source>
        <translation>Nubes dispersas/viento</translation>
    </message>
    <message>
        <source>Sct Strong Storms</source>
        <translation>Fuertes tormentas dispersas</translation>
    </message>
    <message>
        <source>PM T-Storms</source>
        <translation>Tormentas de tarde</translation>
    </message>
    <message>
        <source>Thunderstorms</source>
        <translation>Tormentas</translation>
    </message>
    <message>
        <source>Sunny/Windy</source>
        <translation>Soleado con viento</translation>
    </message>
    <message>
        <source>AM Thunderstorms</source>
        <translation>Tormentas matinales</translation>
    </message>
    <message>
        <source>AM Rain</source>
        <translation>Lluvia matinal</translation>
    </message>
    <message>
        <source>Iso T-Storms/Wind</source>
        <translation>Tormentas aisladas y viento</translation>
    </message>
    <message>
        <source>Rain/Snow</source>
        <translation>Lluvia y nieve</translation>
    </message>
    <message>
        <source>Sct T-Storms/Wind</source>
        <translation>Tormentas dispersas/viento</translation>
    </message>
    <message>
        <source>AM Showers/Wind</source>
        <translation>Chubascos matinales/viento</translation>
    </message>
    <message>
        <source>Sct Snow Showers</source>
        <translation>Chubascos de nieve dispersos</translation>
    </message>
    <message>
        <source>Snow to Ice/Wind</source>
        <translation>Nieve a helada/viento</translation>
    </message>
    <message>
        <source>Snow to Rain</source>
        <translation>Nieve a lluvia</translation>
    </message>
    <message>
        <source>AM Light Rain</source>
        <translation>Llovizna matinal</translation>
    </message>
    <message>
        <source>PM Light Rain</source>
        <translation>Llovizna de tarde</translation>
    </message>
    <message>
        <source>PM Rain</source>
        <translation>Lluvia de tarde</translation>
    </message>
    <message>
        <source>Snow Showers</source>
        <translation>Chubascos de nieve</translation>
    </message>
    <message>
        <source>Rain to Snow</source>
        <translation>Lluvia a nieve</translation>
    </message>
    <message>
        <source>PM Rain/Snow</source>
        <translation>Lluvia/nieve de tarde</translation>
    </message>
    <message>
        <source>Few Showers/Wind</source>
        <translation>Algunos chubascos/viento</translation>
    </message>
    <message>
        <source>Snow/Wind</source>
        <translation>Nieve/viento</translation>
    </message>
    <message>
        <source>PM Rain/Snow Showers</source>
        <translation>Chubascos de lluvia/nieve por la tarde</translation>
    </message>
    <message>
        <source>PM Rain/Snow/Wind</source>
        <translation>Nieve/viento/lluvia por la tarde</translation>
    </message>
    <message>
        <source>Rain/Snow Showers/Wind</source>
        <translation>Chibascos Nieve/lluvia y viento</translation>
    </message>
    <message>
        <source>Rain/Snow/Wind</source>
        <translation>Lluvia/Nieve/Viento</translation>
    </message>
    <message>
        <source>Light Snow</source>
        <translation>Nevada débil</translation>
    </message>
    <message>
        <source>PM Snow</source>
        <translation>Nieve por la tarde</translation>
    </message>
    <message>
        <source>Few Snow Showers/Wind</source>
        <translation>Algo de nieve/viento</translation>
    </message>
    <message>
        <source>Light Snow/Wind</source>
        <translation>Nevada débil/viento</translation>
    </message>
    <message>
        <source>Wintry Mix</source>
        <translation>Ventiscas</translation>
    </message>
    <message>
        <source>AM Wintry Mix</source>
        <translation>Ventiscas de mañana</translation>
    </message>
    <message>
        <source>Hvy Rain/Freezing Rain</source>
        <translation>Fuertes lluvias/granizo</translation>
    </message>
    <message>
        <source>AM Light Snow</source>
        <translation>Dèbiles nevadas matinales</translation>
    </message>
    <message>
        <source>Rain/Freezing Rain</source>
        <translation>Lluvia/granizo</translation>
    </message>
    <message>
        <source>T-Storms/Wind</source>
        <translation>Temporal y viento</translation>
    </message>
    <message>
        <source>Sprinkles</source>
        <translation>Débil llovizna</translation>
    </message>
    <message>
        <source>AM Snow Showers</source>
        <translation>Chubasco de nieve matinal</translation>
    </message>
    <message>
        <source>AM Clouds/PM Sun/Wind</source>
        <translation>Nubes matinales/Claros por la tarde/viento</translation>
    </message>
    <message>
        <source>AM Rain/Snow/Wind</source>
        <translation>Lluvia matinal/nieve/viento</translation>
    </message>
    <message>
        <source>Rain to Snow/Wind</source>
        <translation>Lluvia a nieve/viento</translation>
    </message>
    <message>
        <source>Snow to Wintry Mix</source>
        <translation>Nieve a vendavales</translation>
    </message>
    <message>
        <source>PM Snow Showers/Wind</source>
        <translation>Chubascos de nieve por la tarde/viento</translation>
    </message>
    <message>
        <source>Snow and Ice to Rain</source>
        <translation>Nieve/heladas a lluvia</translation>
    </message>
    <message>
        <source>Heavy Rain</source>
        <translation>Fuertes lluvias</translation>
    </message>
    <message>
        <source>AM Rain/Ice</source>
        <translation>Lluvia/heladas matinales</translation>
    </message>
    <message>
        <source>AM Snow Showers/Wind</source>
        <translation>Chubascos de nieve matinales/viento</translation>
    </message>
    <message>
        <source>AM Light Snow/Wind</source>
        <translation>Nevadas dèbiles matinales/viento</translation>
    </message>
    <message>
        <source>PM Light Rain/Wind</source>
        <translation>Lloviznas por la tarde/viento</translation>
    </message>
    <message>
        <source>AM Light Wintry Mix</source>
        <translation>Ventiscas matinales</translation>
    </message>
    <message>
        <source>PM Light Snow/Wind</source>
        <translation>Nevadas dèbiles por la tarde/viento</translation>
    </message>
    <message>
        <source>Heavy Rain/Wind</source>
        <translation>Fuertes lluvias/viento</translation>
    </message>
    <message>
        <source>PM Snow Shower</source>
        <translation>Chubascos de nieve por la tarde</translation>
    </message>
    <message>
        <source>Snow to Rain/Wind</source>
        <translation>Nieve a lluvia/viento</translation>
    </message>
    <message>
        <source>PM Light Rain/Ice</source>
        <translation>Lloviznas por la tarde/heladas</translation>
    </message>
    <message>
        <source>AM Snow</source>
        <translation>Nieve por la mañana</translation>
    </message>
    <message>
        <source>Snow to Ice</source>
        <translation>Nieve a heladas</translation>
    </message>
    <message>
        <source>Wintry Mix/Wind</source>
        <translation>Vensavales a viento</translation>
    </message>
    <message>
        <source>PM Light Snow</source>
        <translation>Nevadas débiles por la tarde</translation>
    </message>
    <message>
        <source>AM Drizzle</source>
        <translation>Lloviznas matinales</translation>
    </message>
    <message>
        <source>Strong Storms/Wind</source>
        <translation>Fuertes tormentas/viento</translation>
    </message>
    <message>
        <source>PM Drizzle</source>
        <translation>Lloviznas por la tarde</translation>
    </message>
    <message>
        <source>Drizzle</source>
        <translation>Lloviznas</translation>
    </message>
    <message>
        <source>AM Light Rain/Wind</source>
        <translation>Lluvia dèbil por la mañana/viento</translation>
    </message>
    <message>
        <source>AM Rain/Wind</source>
        <translation>Lluvia matinal/viento</translation>
    </message>
    <message>
        <source>Wintry Mix to Snow</source>
        <translation>Vendavales a nieve</translation>
    </message>
    <message>
        <source>Snow Showers/Windy</source>
        <translation>Chubascos de nieve/viento</translation>
    </message>
    <message>
        <source>Light Rain Shower</source>
        <translation>Chubascos de lluvia débil</translation>
    </message>
    <message>
        <source>Light Rain with Thunder</source>
        <translation>Lluvias débiles con truenos</translation>
    </message>
    <message>
        <source>Light Drizzle</source>
        <translation>Llovizna débl</translation>
    </message>
    <message>
        <source>Mist</source>
        <translation>Neblizna</translation>
    </message>
    <message>
        <source>Smoke</source>
        <translation>Poca visibilidad</translation>
    </message>
    <message>
        <source>Haze</source>
        <translation>Calina</translation>
    </message>
    <message>
        <source>Light Snow Shower</source>
        <translation>Chubascos débiles de nieve</translation>
    </message>
    <message>
        <source>Light Snow Shower/ Windy</source>
        <translation>Chubascos débiles de nieve/viento</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Despejado</translation>
    </message>
    <message>
        <source>A Few Clouds</source>
        <translation>Algunas nubes</translation>
    </message>
    <message>
        <source>Fair</source>
        <translation>Bueno</translation>
    </message>
</context>
<context>
    <name>String::WindDirection</name>
    <message>
        <source>N</source>
        <translation></translation>
    </message>
    <message>
        <source>NNE</source>
        <translation></translation>
    </message>
    <message>
        <source>NE</source>
        <translation></translation>
    </message>
    <message>
        <source>E</source>
        <translation></translation>
    </message>
    <message>
        <source>SE</source>
        <translation></translation>
    </message>
    <message>
        <source>SSE</source>
        <translation></translation>
    </message>
    <message>
        <source>S</source>
        <translation></translation>
    </message>
    <message>
        <source>SSW</source>
        <translation>SSO</translation>
    </message>
    <message>
        <source>SW</source>
        <translation>SO</translation>
    </message>
    <message>
        <source>W</source>
        <translation>O</translation>
    </message>
    <message>
        <source>NW</source>
        <translation>NO</translation>
    </message>
    <message>
        <source>NNW</source>
        <translation></translation>
    </message>
    <message>
        <source>ENE</source>
        <translation></translation>
    </message>
    <message>
        <source>ESE</source>
        <translation></translation>
    </message>
    <message>
        <source>WSW</source>
        <translation>OSO</translation>
    </message>
    <message>
        <source>WNW</source>
        <translation>ONO</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>loading...</source>
        <translation>Cargando...</translation>
    </message>
    <message>
        <source>[ retrieving weather data ... ]</source>
        <translation>[ obteniendo datos meteorológicos ... ]</translation>
    </message>
    <message>
        <source>current conditions</source>
        <translation>el tiempo ahora</translation>
    </message>
    <message>
        <source>Humidity</source>
        <translation>Humedad</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation>Presión</translation>
    </message>
    <message>
        <source>Wind</source>
        <translation>Viento</translation>
    </message>
    <message>
        <source>Visibility</source>
        <translation>Visibilidat</translation>
    </message>
    <message>
        <source>Wind Chill</source>
        <translation>Sensación</translation>
    </message>
    <message>
        <source>UV Index</source>
        <translation>Radiación solar (UV)</translation>
    </message>
    <message>
        <source>extended forecast</source>
        <translation>próximos días</translation>
    </message>
    <message>
        <source>LO</source>
        <translation>MIN</translation>
    </message>
    <message>
        <source>HI</source>
        <translation>MAX</translation>
    </message>
    <message>
        <source>today&apos;s forecast</source>
        <translation>previsión para hoy</translation>
    </message>
    <message>
        <source>tomorrow&apos;s outlook</source>
        <translation>previsión para mañana</translation>
    </message>
    <message>
        <source>Forecast for</source>
        <translation>Previsió per al</translation>
    </message>
    <message>
        <source>doppler radar</source>
        <translation>Imagen del radar</translation>
    </message>
    <message>
        <source>Map Unavailable</source>
        <translation>Mapa no disponible</translation>
    </message>
    <message>
        <source>RAIN</source>
        <translation>LLUVIA</translation>
    </message>
    <message>
        <source>MIX/ICE</source>
        <translation>HELADA</translation>
    </message>
    <message>
        <source>SNOW</source>
        <translation>NIEVE</translation>
    </message>
    <message>
        <source>LIGHT</source>
        <translation>LIGERA</translation>
    </message>
    <message>
        <source>HEAVY</source>
        <translation>FUERTE</translation>
    </message>
    <message>
        <source>Enter Zip Code</source>
        <translation>Código Postal</translation>
    </message>
    <message>
        <source>weather setup</source>
        <translation>Configuración de &quot;El Tiempo&quot;</translation>
    </message>
    <message>
        <source>To save, press &apos;i&apos; - to cancel, hit escape</source>
        <translation>Para guardar, pulse &apos;i&apos; - para cancelar, para cancelar salga</translation>
    </message>
    <message>
        <source>COLD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>COLDEST</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CLOUD TEMPERATURE</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Weather</name>
    <message>
        <source> is invalid)</source>
        <translation>es inválido)</translation>
    </message>
    <message>
        <source>   No Location Set, Please read the README</source>
        <translation>  No hay una estación definida, lea el README</translation>
    </message>
    <message>
        <source>Configuring MythWeather...</source>
        <translation>Configurando MythWeather...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select unit conversion...</source>
        <translation>Escoja unidad de conversión con la flecha derecha...</translation>
    </message>
    <message>
        <source>Weather Units</source>
        <translation>Unidad</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Estación</translation>
    </message>
    <message>
        <source>Aggressiveness</source>
        <translation>Tipo de conexión</translation>
    </message>
    <message>
        <source>Configuration Saved...</source>
        <translation>Configuración guardada...</translation>
    </message>
    <message>
        <source>Retrieving weather data...</source>
        <translation>Obteniendo información...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select your location...</source>
        <translation>Escoja la estación con la flecha derecha...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select the aggressiveness level...</source>
        <translation>Escoja el tipo de conexión con la flecha derecha...</translation>
    </message>
    <message>
        <source> 1  High Speed Connection</source>
        <translation>1  Alta velocidad</translation>
    </message>
    <message>
        <source> 8  Medium Speed Connection</source>
        <translation>8  Velocidad media</translation>
    </message>
    <message>
        <source> 15 Low Speed Connection</source>
        <translation>15 Conexión de baja velocidad</translation>
    </message>
    <message>
        <source>Obtaining initial weather data...</source>
        <translation>Obteniendo datos iniciales...</translation>
    </message>
    <message>
        <source>Updating weather data...</source>
        <translation>Actualizando información del tiempo...</translation>
    </message>
    <message>
        <source>Calm</source>
        <translation>Calma </translation>
    </message>
    <message>
        <source> at </source>
        <translation> a </translation>
    </message>
    <message>
        <source>Unlimited</source>
        <translation>ilimitada</translation>
    </message>
    <message>
        <source> (minimal)</source>
        <translation>(mínima)</translation>
    </message>
    <message>
        <source> (moderate)</source>
        <translation>(moderada)</translation>
    </message>
    <message>
        <source> (high)</source>
        <translation>(alta)</translation>
    </message>
    <message>
        <source> (extreme)</source>
        <translation>(extrema)</translation>
    </message>
    <message>
        <source>Today a high of </source>
        <translation>Hoy hay una máxima de </translation>
    </message>
    <message>
        <source> and a low of </source>
        <translation> y una mínima de </translation>
    </message>
    <message>
        <source>. Currently there is a humidity of </source>
        <translation>. La humedad actual es de </translation>
    </message>
    <message>
        <source>% and the winds are</source>
        <translation>% y un viento </translation>
    </message>
    <message>
        <source> calm.</source>
        <translation>en calma. </translation>
    </message>
    <message>
        <source> coming in at </source>
        <translation> soplando a </translation>
    </message>
    <message>
        <source> mph from the </source>
        <translation>mph dirección </translation>
    </message>
    <message>
        <source> Km/h from the </source>
        <translation> km/h dirección </translation>
    </message>
    <message>
        <source> Visibility will be unlimited for today.</source>
        <translation> La visibilidad hoy es ilimitada.</translation>
    </message>
    <message>
        <source> Visibility conditions are unknown.</source>
        <translation> Se desconoce la visibilidad.</translation>
    </message>
    <message>
        <source> There will be a visibility of </source>
        <translation> Habrá una visibilidad de </translation>
    </message>
    <message>
        <source> miles.</source>
        <translation> millas.</translation>
    </message>
    <message>
        <source> km.</source>
        <translation> km.</translation>
    </message>
    <message>
        <source>SUN</source>
        <translation type="obsolete">DOM</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
    <message>
        <source>MON</source>
        <translation type="obsolete">LUN</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Lunes</translation>
    </message>
    <message>
        <source>TUE</source>
        <translation type="obsolete">MAR</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Martes</translation>
    </message>
    <message>
        <source>WED</source>
        <translation type="obsolete">MIE</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Miércoles</translation>
    </message>
    <message>
        <source>THU</source>
        <translation type="obsolete">JUE</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Jueves</translation>
    </message>
    <message>
        <source>FRI</source>
        <translation type="obsolete">VIE</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Viernes</translation>
    </message>
    <message>
        <source>SAT</source>
        <translation type="obsolete">SAB</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <source>Date Error</source>
        <translation>Error en la fecha</translation>
    </message>
    <message>
        <source>Tomorrow expect a high of </source>
        <translation>Mañana se espera una máxima de </translation>
    </message>
    <message>
        <source>Expected conditions: </source>
        <translation>Previsión: </translation>
    </message>
    <message>
        <source>Weather data from: </source>
        <translation>Datos del tiempo de: </translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Actualizando...</translation>
    </message>
    <message>
        <source> (Not All Information Available)</source>
        <translation>(No toda la información está disponible)</translation>
    </message>
    <message>
        <source>*** Invalid Area ID Entered *** Use a valid area id.</source>
        <translation type="obsolete">*** ID de Area inválido *** Use uno correcto.</translation>
    </message>
    <message>
        <source>Weather Data Not Available</source>
        <translation type="obsolete">Datos del tiempo no disponibles</translation>
    </message>
    <message>
        <source>!!! Timeout Limit !!! Change aggressiveness level.</source>
        <translation type="obsolete">¡¡¡ Tiempo de espera excedido !!! Cambie el tipo de conexión,</translation>
    </message>
    <message>
        <source>*** Invalid Area ID or Server Error ***</source>
        <translation>*** Estación desconocida o error del servidor ***</translation>
    </message>
    <message>
        <source>Imperial (Fahrenheit, in, etc)</source>
        <translation></translation>
    </message>
    <message>
        <source>Metric (Celsius, kPa, etc)</source>
        <translation></translation>
    </message>
    <message>
        <source> F</source>
        <translation></translation>
    </message>
    <message>
        <source> C</source>
        <translation></translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
    <message>
        <source> - PAUSED -</source>
        <translation>- PAUSA -</translation>
    </message>
    <message>
        <source>doppler radar</source>
        <translation type="unfinished">Imagen del radar</translation>
    </message>
    <message>
        <source>satellite image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
